GridSectionedAdapter class

Constructors

GridSectionedAdapter(List<SectionImage> items, dynamic onItemClick)

Properties

hashCode → int
The hash code for this object.
no setterinherited
items ↔ List<SectionImage>
getter/setter pair
itemsTile ↔ List<ItemTile>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getView() → Widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited