SectionImage class

Constructors

SectionImage(String image, String title, bool section)

Properties

hashCode → int
The hash code for this object.
no setterinherited
image ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
section ↔ bool
getter/setter pair
title ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited